<?php

//    include/functions.inc.php
//    General functions
//
//    Part of the ht://Check package
//
//    Copyright (c) 1999-2002 Comune di Prato - Prato - Italy
//    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
//
//    For copyright details, see the file COPYING in your distribution
//    or the GNU General Public License version 2 or later 
//    <http://www.gnu.org/copyleft/gpl.html>
//
//    $Id: functions.inc.php,v 1.3 2002/02/12 11:18:07 angusgb Exp $

if ( defined( '__FUNCTIONS_INC' ) ) return;
define( '__FUNCTIONS_INC', 1 );

include ("./include/global.inc.php");

/**
 * return a list of HTML special chars and their encodings
 *
 * <code>get_html_entities</code> returns an array of HTML special
 * characters and their encoding (like '<' => '&lt;').
 * 
 * On PHP4 or later it is equal to
 * <code>get_html_translation_table(HTML_ENTITIES)</code>, in fact it calls
 * just that.
 *
 * In PHP3 it returns a list similar to what
 * <code>get_html_translation_table()</code> would return (unfortunatly it does
 * not exist in PHP3).
 *
 * @returns	array	list of HTML special chars and their encodings
 */
function get_html_entities () {
	// Find out which PHP version we are running.
	// 
	// PHP versions are major.minor.patchlevel.
	// Exploding (splitting) the version number and comparing.  the first array
	// field tells us whether we're on php 4 or later and can therefore use
	// get_html_translation_table() or whether we are on php3 and need to work
	// around it.
	$version_split = explode ('.', phpversion ());
	if ($version_split[0] <= 3) {
		// What a pity - we need to do all the hard work ourselves
		$table = array(
			'' => '&nbsp;',
			'' => '&iexcl;',
			'' => '&cent;',
			'' => '&pound;',
			'' => '&curren;',
			'' => '&yen;',
			'' => '&brvbar;',
			'' => '&sect;',
			'' => '&uml;',
			'' => '&copy;',
			'' => '&ordf;',
			'' => '&laquo;',
			'' => '&not;',
			'' => '&shy;',
			'' => '&reg;',
			'' => '&macr;',
			'' => '&deg;',
			'' => '&plusmn;',
			'' => '&sup2;',
			'' => '&sup3;',
			'' => '&acute;',
			'' => '&micro;',
			'' => '&para;',
			'' => '&middot;',
			'' => '&cedil;',
			'' => '&sup1;',
			'' => '&ordm;',
			'' => '&raquo;',
			'' => '&frac14;',
			'' => '&frac12;',
			'' => '&frac34;',
			'' => '&iquest;',
			'' => '&Agrave;',
			'' => '&Aacute;',
			'' => '&Acirc;',
			'' => '&Atilde;',
			'' => '&Auml;',
			'' => '&Aring;',
			'' => '&AElig;',
			'' => '&Ccedil;',
			'' => '&Egrave;',
			'' => '&Eacute;',
			'' => '&Ecirc;',
			'' => '&Euml;',
			'' => '&Igrave;',
			'' => '&Iacute;',
			'' => '&Icirc;',
			'' => '&Iuml;',
			'' => '&ETH;',
			'' => '&Ntilde;',
			'' => '&Ograve;',
			'' => '&Oacute;',
			'' => '&Ocirc;',
			'' => '&Otilde;',
			'' => '&Ouml;',
			'' => '&times;',
			'' => '&Oslash;',
			'' => '&Ugrave;',
			'' => '&Uacute;',
			'' => '&Ucirc;',
			'' => '&Uuml;',
			'' => '&Yacute;',
			'' => '&THORN;',
			'' => '&szlig;',
			'' => '&agrave;',
			'' => '&aacute;',
			'' => '&acirc;',
			'' => '&atilde;',
			'' => '&auml;',
			'' => '&aring;',
			'' => '&aelig;',
			'' => '&ccedil;',
			'' => '&egrave;',
			'' => '&eacute;',
			'' => '&ecirc;',
			'' => '&euml;',
			'' => '&igrave;',
			'' => '&iacute;',
			'' => '&icirc;',
			'' => '&iuml;',
			'' => '&eth;',
			'' => '&ntilde;',
			'' => '&ograve;',
			'' => '&oacute;',
			'' => '&ocirc;',
			'' => '&otilde;',
			'' => '&ouml;',
			'' => '&divide;',
			'' => '&oslash;',
			'' => '&ugrave;',
			'' => '&uacute;',
			'' => '&ucirc;',
			'' => '&uuml;',
			'' => '&yacute;',
			'' => '&thorn;',
			'&' => '&amp;',
			'"' => '&quot;',
			'<' => '&lt;',
			'>' => '&gt;'
		);
	} else {
		// enjoy, PHP4
		$table = get_html_translation_table(HTML_ENTITIES);
	};
	// Translating regular braces shouldn't be required since
	// square brackets are already converted.
	$table['('] = '&#40;';
	$table[')'] = '&#41;';
};

// Get the translation table for characters
$XSS_table = get_html_entities(HTML_ENTITIES);

/**
 * Convert special characters to HTML entities 
 *
 * Some characters (like '<') are special in HTML. This function replaces those
 * characters with their save encodings similar to
 * <code>htmlspecialchars()</code>.
 *
 * The only difference is that it replaces far more characters (the entire
 * table returned by get_html_translation_table or something similar in case of
 * PHP3. See the documentation of <code>get_html_entities</code>).
 *
 * @param   string    The string to get cleaned
 * @returns string    The cleaned string.
 */
/*
	An alternative code in the php3 path would be:

		while (list($key,$value) = each($XSS_table)) {
			$str = str_replace($key, $value, $str);
		}
		return $str;

	However I (weasel) think that the while loop might be more
	efficient. Also it does not have the limitation that '&' must
	be the first entry in the XSS_table table.
*/
function WriteHTML($str) {
	global $XSS_table;
	// Same game as in get_html_entities(): Find the php_version
	$version_split = explode ('.', phpversion ());
	if ($version_split[0] <= 3) {
		$result = '';
		for ($i=0; $i < strlen($str); $i++) {
			$c = $str[$i];
			if (isset($XSS_table[$c]))
				$result .= $XSS_table[$c];
			else
				$result .= $c;
		};
		return $result;
	} else {
		return strtr($str, $XSS_table);
	}
}

function DisplayErrMsg($errmsg)
{

?>
   <B><?php echo WriteHTML ($errmsg); ?></B><BR>
<?php

}


///////
   // Page Management
///////

function WritePageLink($initpage,$pagesize,$count,$dbname,$otherinfo="")
{
   $nextoffset=$initpage+$pagesize;
   $justone=false;
   global $PHP_SELF;
   global $strNext;
   global $strPrevious;

   if ($initpage >= $pagesize)
   {
      $justone=true;
      
      if ($initpage >= $pagesize*2)
      {
         // Show the first page Link
         global $strFirst;
?>
   | <A href="<?php echo $PHP_SELF; ?>?dbname=<?php echo $dbname; ?>&initpage=0&pagesize=<?php echo $pagesize; ?>&count=<?php echo $count; ?><?php echo $otherinfo; ?>>"><?php echo $strFirst; ?></A>
<?php         
      }
?>
   | <A href="<?php echo $PHP_SELF; ?>?dbname=<?php echo $dbname; ?>&initpage=<?php echo $initpage-$pagesize; ?>&pagesize=<?php echo $pagesize; ?>&count=<?php echo $count; ?><?php echo $otherinfo; ?>"><?php echo $strPrevious; ?></A>
<?php
   }
      
   if ($nextoffset < $count)
   {
      $justone=true;
?>
   | <A href="<?php echo $PHP_SELF; ?>?dbname=<?php echo $dbname; ?>&initpage=<?php echo $nextoffset; ?>&pagesize=<?php echo $pagesize; ?>&count=<?php echo $count; ?><?php echo $otherinfo; ?>"><?php echo $strNext; ?></A>
<?php
      if ($nextoffset+$pagesize < $count)
      {
         // Show the last page Link
         global $strLast;
         $lastoffset=((int)((int)($count-1)/$pagesize))*$pagesize;
?>
   | <A href="<?php echo $PHP_SELF; ?>?dbname=<?php echo $dbname; ?>&initpage=<?php echo $lastoffset; ?>&pagesize=<?php echo $pagesize; ?>&count=<?php echo $count; ?><?php echo $otherinfo; ?>"><?php echo $strLast; ?></A>
<?php         
      }

   }

   if ($justone) echo "|";
}


function ExpiredSession()
{
?>
<?php echo $strSessionExpired; ?><BR>
<?php
}


function GetTextString($str)
{
   $str2 = "\$str" . (string) $str;
   eval("global $str2;");
   eval("\$tmp=$str2;");
   return $tmp;
}

function GetURL($url)
{
   global $MaxURLStrLength;
   if ($MaxURLStrLength > 0 && strlen($url) > $MaxURLStrLength)
      return WriteHTML(substr($url, 0, $MaxURLStrLength) . '[...]');
   else return WriteHTML($url);
}

?>
